package com.ruoyi.tuya.service;

import java.util.List;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.tuya.domain.BusSupplierRelease;

/**
 * 平台报价单Service接口
 *
 * @author zf
 * @date 2022-07-21
 */
public interface IBusSupplierReleaseService
{
    /**
     * 查询平台报价单
     *
     * @param id 平台报价单主键
     * @return 平台报价单
     */
    public BusSupplierRelease selectBusSupplierReleaseById(Long id);

    /**
     * 查询平台报价单列表
     *
     * @param busSupplierRelease 平台报价单
     * @return 平台报价单集合
     */
    public List<BusSupplierRelease> selectBusSupplierReleaseList(BusSupplierRelease busSupplierRelease);

    /**
     * 新增平台报价单
     *
     * @param busSupplierRelease 平台报价单
     * @return 结果
     */
    public int insertBusSupplierRelease(BusSupplierRelease busSupplierRelease);

    /**
     * 修改平台报价单
     *
     * @param busSupplierRelease 平台报价单
     * @return 结果
     */
    public int updateBusSupplierRelease(BusSupplierRelease busSupplierRelease);

    /**
     * 批量删除平台报价单
     *
     * @param ids 需要删除的平台报价单主键集合
     * @return 结果
     */
    public int deleteBusSupplierReleaseByIds(Long[] ids);

    /**
     * 删除平台报价单信息
     *
     * @param id 平台报价单主键
     * @return 结果
     */
    public int deleteBusSupplierReleaseById(Long id);


    /**
     * 新增平台报价单删除备份
     *
     * @param ids 平台报价单id
     * @return 结果
     */
    public int insertBusSupplierReleaseDiscard(Long[] ids);

    /**
     * 修改热门标识
     *
     * @param busSupplierRelease 平台报价单
     * @return 结果
     */
    public int updateHotForm(BusSupplierRelease busSupplierRelease);

}
